Learn R Programming

boxcoxmix (version 0.42)

boxcoxmix-package: Box-Cox-Type Transformations for Linear and Logistic Models with Random Effects

Description

Box-Cox-type transformations for linear and logistic models with random effects using non-parametric profile maximum likelihood estimation. The main functions are optim.boxcox() for linear models with random effects and boxcoxtype() for logistic models with random effects.

Arguments

Author

Amani Almohaimeed and Jochen Einbeck

Details

Package:boxcoxmix
Type:Package
Version:0.28
Date:2020-09-17
License:GPL (>=3)

References

Box G. and Cox D. (1964). An analysis of transformations. Journal of the Royal Statistical Society. Series B (Methodological), pages 211-252.

Aitkin, M. A., Francis, B., Hinde, J., and Darnell, R. (2009). Statistical modelling in R. Oxford University Press Oxford.

Jochen Einbeck, Ross Darnell and John Hinde (2014). npmlreg: Nonparametric maximum likelihood estimation for random effect models. R package version 0.46-1.

R Core Team (2016). R: A language and environment for statistical computing. R Foundation for Statistical Computing, Vienna, Austria. URL https://www.R-project.org/.

Maintainer: Amani Almohaimeed <amani.almohaimeed@gmail.com>