Learn R Programming

boxcoxmix (version 0.28)

print.boxcoxmix: Summary of boxcoxmix functions

Description

summary() and print() are generic functions used to produce the results of the functions: np.boxcoxmix(), optim.boxcox() and tolfind.boxcox().

Usage

# S3 method for boxcoxmix
print(x, digits = max(3, getOption("digits") - 3), na.print = "", ...)

# S3 method for boxcoxmixpure print(x, digits = max(3, getOption("digits") - 3), na.print = "", ...)

# S3 method for boxcoxmix summary(object, digits = max(3, getOption("digits") - 3), ...)

# S3 method for boxcoxmixpure summary(object, digits = max(3, getOption("digits") - 3), ...)

Arguments

x

an object for which a summary is desired.

digits

an integer number format.

na.print

a character string which is used to indicate NA values output format.

additional arguments.

object

an object for which a summary is desired.

Details

Summary of boxcoxmix functions