summary() and print() are generic functions used to produce the results of the functions:
np.boxcoxmix(), optim.boxcox() and tolfind.boxcox().
# S3 method for boxcoxmix
print(x, digits = max(3, getOption("digits") - 3), na.print = "", ...)# S3 method for boxcoxmixpure
print(x, digits = max(3, getOption("digits") - 3), na.print = "", ...)
# S3 method for boxcoxmix
summary(object, digits = max(3, getOption("digits") - 3), ...)
# S3 method for boxcoxmixpure
summary(object, digits = max(3, getOption("digits") - 3), ...)
an object for which a summary is desired.
an integer number format.
a character string which is used to indicate NA values output format.
additional arguments.
an object for which a summary is desired.
Summary of boxcoxmix functions